aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--src/github/daneren2005/dsub/service/DownloadServiceImpl.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/github/daneren2005/dsub/service/DownloadServiceImpl.java b/src/github/daneren2005/dsub/service/DownloadServiceImpl.java
index 8b069217..51c32091 100644
--- a/src/github/daneren2005/dsub/service/DownloadServiceImpl.java
+++ b/src/github/daneren2005/dsub/service/DownloadServiceImpl.java
@@ -514,8 +514,8 @@ public class DownloadServiceImpl extends Service implements DownloadService {
if(currentPlaying != null && currentPlaying.getSong() instanceof PodcastEpisode) {
int duration = getPlayerDuration();
- // Make sure > 95% of the way through
- int cutoffPoint = (int)(duration * 0.95);
+ // Make sure > 90% of the way through
+ int cutoffPoint = (int)(duration * 0.90);
if(duration > 0 && cachedPosition > cutoffPoint) {
currentPlaying.delete();
}